@@ -3,4 +3,4 @@ from midi_generator.config import *
 from midi_generator.genetic import *
 from midi_generator.output import *
 from midi_generator.syncopation import *
-from cli import print_cli
\ No newline at end of file
+from midi_generator.cli import print_cli
\ No newline at end of file
